# Copyright (C) 2020 Hannu Viitala
#
# The source code in this file is released under the MIT license.
# Go to http://opensource.org/licenses/MIT for the full license details.
#

# *** A TILEMAP DEMO FOR THE POKITTO MICROPYTHON ***
# Note: Works in the lores or the hires mode, both in TAS and normal.

import upygame as pygame
import data

# Setup the screen buffer
pygame.display.init(False)
pygame.display.set_palette_16bit([
	4195,16678,12717,19017,13092,33382,53801,29580,23545,54245,33972,27973,28185,54611,57003,57210
]);
screen = pygame.display.set_mode() # full screen

# Initialise the mp.
tilemap = pygame.tilemap.Tilemap(24,24,data.mapPixels1)
tilemap.set_tile(0xb, 16, 16, data.green16);
tilemap.set_tile(0x5, 16, 16, data.tree16);
tilemap.set_tile(0x4, 16, 16, data.grass16);
tilemap.set_tile(0x8, 16, 16, data.water16);

# The main loop
vx = 0;
vy = 0;
x = -120;
y = -100;
mapW = 24*16 # 24 tiles of 16 pixels
mapH = 24*16 # 24 tiles of 16 pixels
screenW = screen.get_rect().width
screenH = screen.get_rect().height
heroOnScreenX = screenW // 2
heroOnScreenY = screenH // 2

while True:

    # Read keys
    eventtype = pygame.event.poll()
    if eventtype != pygame.NOEVENT:
        if eventtype.type == pygame.KEYDOWN:
            if eventtype.key == pygame.K_RIGHT: vx = -1
            if eventtype.key == pygame.K_LEFT:  vx = 1
            if eventtype.key == pygame.K_UP:    vy = 1
            if eventtype.key == pygame.K_DOWN:  vy = -1
        if eventtype.type == pygame.KEYUP:
            if eventtype.key == pygame.K_RIGHT: vx = 0
            if eventtype.key == pygame.K_LEFT:  vx = 0
            if eventtype.key == pygame.K_UP:    vy = 0
            if eventtype.key == pygame.K_DOWN:  vy = 0

    # Move.
    oldX = x
    oldY = y
    x += vx
    y += vy

    # Check the map tile under the girl.
    girlCenterInMapX = (heroOnScreenX + 6) - x
    girlCerterInMapY = (heroOnScreenY + 7) - y
    tileId = tilemap.get_tile_id(girlCenterInMapX, girlCerterInMapY, 16)

    # If the tile is not grass, do not move.
    if(tileId != 0xb):
        x = oldX
        y = oldY

    # Check for out of bounds.
    if(x>0): x=0
    if(x + mapW < screenW): x = screenW - mapW
    if(y>0): y=0
    if(y + mapH < screenH): y = screenH - mapH

    # Draw
    tilemap.draw(x, y)
    pygame.draw.text(0, 0, "Tilemap demo", 15);
    screen.blit(data.girl12x15, heroOnScreenX, heroOnScreenY)
    pygame.display.flip()